# react-native-confirmation-code-field

[![npm](https://img.shields.io/npm/v/react-native-confirmation-code-field.svg)](https://www.npmjs.com/package/react-native-confirmation-code-field)
[![npm downloads](https://img.shields.io/npm/dm/react-native-confirmation-code-field.svg)](https://www.npmtrends.com/react-native-confirmation-code-field)
[![Travis](https://img.shields.io/travis/retyui/react-native-confirmation-code-field.svg?label=unix)](https://travis-ci.org/retyui/react-native-confirmation-code-field)

A react-native confirmation code field compatible with iOS, Android and Web Platforms (based on [this](https://github.com/ttdung11t2/react-native-confirmation-code-input) project [Migration Guide](docs/migration.md))

### Links

- [Documentation](API.md)

### Component features:

- 🔮 Simple. Easy to use;
- 🚮 Clearing part of the code by clicking on the cell;
- 🍎 Support "fast paste SMS-code" on iOS. And custom code paste for Android;
- ⚡ TextInput `ref` support;
- 🛠 Extendable and hackable;
- 🤓 Readable [changelog](CHANGELOG.md).

## Screenshots

<a href="https://github.com/retyui/react-native-confirmation-code-field/tree/master/examples/src/realDemo/AnimatedExample"><img width="250" src="https://raw.githubusercontent.com/retyui/react-native-confirmation-code-field/master/docs/img/animated.gif"/></a><a href="https://github.com/retyui/react-native-confirmation-code-field/tree/master/examples/src/realDemo/RedExample"><img width="250" src="https://raw.githubusercontent.com/retyui/react-native-confirmation-code-field/master/docs/img/red.gif"/></a><a href="https://github.com/retyui/react-native-confirmation-code-field/tree/master/examples/src/realDemo/DarkExample"><img width="250" src="https://raw.githubusercontent.com/retyui/react-native-confirmation-code-field/master/docs/img/dark.gif"/></a>

## Install

```sh
yarn add react-native-confirmation-code-field
```

## How it work

I use an invisible `<TextInput/>` component that absolutely stretched over `<Cell/>` components to have ability paste code normally on iOS [issue#25](https://github.com/retyui/react-native-confirmation-code-field/issues/25#issuecomment-446497934)

```js
import React, {useState} from 'react';
import {Text} from 'react-native';

import {CodeFiled, Cursor} from 'react-native-confirmation-code-field';

const CELL_COUNT = 6;

const App = () => {
  const [value, setValue] = useState('12');

  return (
    <CodeFiled
      value={value}
      onChangeText={setValue}
      cellCount={CELL_COUNT}
      renderCell={({index, symbol, isFocused}) => (
        //
        <Text key={index}>{symbol || (isFocused ? <Cursor /> : null)}</Text>
      )}
    />
  );
};
```
